<?php
namespace app\user\event;

class Sql
{
    /**
    * 安装时触发
    * @return bool 只有返回true时才会往下执行
    */
	public function install()
    {
        //初始配置
        $this->saveConfig();
        
        //初始路由
        $this->saveRoute();
        
        //初始用户
        $this->saveUser();
        
        //初始权限
        $this->saveAuth();
        
        //初始菜单
        $this->saveNavs();

        //返回结果
        return true;
	}
    
    /**
    * 升级时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function upgrade()
    {
        if( !\daicuo\Apply::updateStatus('user', 'enable') ){
            return false;
        }
        return true;
    }
    
    /**
    * 卸载时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function remove()
    {
        return $this->unInstall();
    }
    
    /**
    * 删除时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function unInstall()
    {
        //删除插件配置
        \daicuo\Op::delete_module('user');
        //删除插件分类
        \daicuo\Term::delete_module('user');
        //删除插件用户
        \daicuo\User::delete_module('user');
        //直接返回结果
        return true;
	}
    
    //批量写入插件初始配置
    private function saveConfig()
    {
        return \daicuo\Op::write([
            'theme'                => 'default',
            'theme_wap'            => 'default',
            'page_size'            => 20,
            'register_score'       => 0,
            'title_login'          => '用户登录',
            'keywords_login'       => '用户登录,登录发布网址',
            'description_login'    => '请登录后再提交发布您的网址',
            'title_register'       => '用户注册',
            'keywords_register'    => '加入我们,免费注册',
            'description_register' => '请先注册后再提交发布您的网址',
            'title_index'          => '用户中心',
            'keywords_index'       => '用户中心平台',
            'description_index'    => '欢迎回到呆错分类导航系统用户中心',
        ],'user','system','config','0','yes');
    }
    
    //批量添加路由伪静态
    private function saveRoute()
    {
        config('common.validate_name', 'common/Route');
        config('common.validate_scene', '');
        config('common.where_slug_unique', '');
        return \daicuo\Route::save_all([
            [
                'rule'        => 'user$',
                'address'     => 'user/index/index',
                'method'      => 'get',
                'op_module'   => 'user',
                'op_controll' => 'index',
                'op_action'   => 'index',
            ],
            [
                'rule'        => 'user/[:slug]$',
                'address'     => 'user/index/slug',
                'method'      => 'get',
                'op_module'   => 'user',
                'op_controll' => 'index',
                'op_action'   => 'index',
            ],
            [
                'rule'        => 'login$',
                'address'     => 'user/index/login',
                'method'      => '*',
                'op_module'   => 'user',
                'op_controll' => 'index',
                'op_action'   => 'login',
            ],
            [
                'rule'        => 'register$',
                'address'     => 'user/index/register',
                'method'      => '*',
                'op_module'   => 'user',
                'op_controll' => 'index',
                'op_action'   => 'register',
            ],
            [
                'rule'        => 'ucenter$',
                'address'     => 'user/center/index',
                'method'      => 'get',
                'op_module'   => 'user',
                'op_controll' => 'ucenter',
                'op_action'   => 'index',
            ],
            [
                'rule'        => 'logout$',
                'address'     => 'user/index/logout',
                'method'      => 'get',
                'op_module'   => 'user',
                'op_controll' => 'index',
                'op_action'   => 'logout',
            ],
        ]);
    }
    
    //批量添加初始用户
    private function saveUser()
    {
        config('common.validate_name', '');
        config('common.validate_scene', '');
        config('common.where_slug_unique', '');
        DcConfigMerge('custom_fields.user_meta', ['user_pid', 'user_score']);
        return \daicuo\User::save_all([
            [
                'user_name'         => 'user1',
                'user_pass'         => 'user1',
                'user_email'        => 'user1@daicuo.org',
                'user_mobile'       => '13800138001',
                'user_status'       => 'normal',
                'user_module'       => 'user',
                'user_capabilities' => 'guset',
                'user_slug'         => 'userone',
                'user_score'        => 0,
                'user_pid'          => 0,
            ],
            [
                'user_name'         => 'user1',
                'user_pass'         => 'user2',
                'user_email'        => 'user2@daicuo.org',
                'user_mobile'       => '13800138002',
                'user_status'       => 'normal',
                'user_module'       => 'user',
                'user_capabilities' => 'guset',
                'user_slug'         => 'usertwo',
                'user_score'        => 0,
                'user_pid'          => 0,
            ],
        ]);
    }
    
    //批量添加权限
    private function saveAuth()
    {
        config('common.validate_name', '');
        config('common.validate_scene', '');
        config('common.where_slug_unique', '');
        return \daicuo\Op::save_all([
            [
                'op_name'       => 'editor',
                'op_value'      => 'admin/addon/index?module=index&action=index',
                'op_module'     => 'user',
                'op_controll'   => 'system',
                'op_action'     => 'auth',
                'op_order'      => 0,
                'op_status'     => 'normal',
            ],
            [
                'op_name'       => 'editor',
                'op_value'      => 'admin/addon/index?module=index&action=create',
                'op_module'     => 'user',
                'op_controll'   => 'system',
                'op_action'     => 'auth',
                'op_order'      => 0,
                'op_status'     => 'normal',
            ],
            [
                'op_name'       => 'editor',
                'op_value'      => 'admin/addon/index?module=index&action=edit',
                'op_module'     => 'user',
                'op_controll'   => 'system',
                'op_action'     => 'auth',
                'op_order'      => 0,
                'op_status'     => 'normal',
            ],
        ]);
    }
    
    //批量添加默认导航菜单
    private function saveNavs()
    {
        //简易导航插件是否安装
        $applys = config('common.site_applys');
        if(!$applys['navs']){
             return false;
        }
        //验证条件
        config('common.validate_name', 'navs/Common');
        config('common.validate_scene', '');
        config('common.where_slug_unique', '');
        //批量添加导航
        $result = model('navs/Db','loglic')->save_all([
            [
                'nav_text'        => '登录',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'index',
                'nav_action'      => 'login',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-sign-in',
                'nav_active'      => 'userindexlogin',
                'op_module'       => 'user',
                'op_controll'     => 'navbar',
                'op_action'       => 'login',
                'op_order'        => 901,
            ],
            [
                'nav_text'        => '注册',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'index',
                'nav_action'      => 'register',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-user-plus',
                'nav_active'      => 'userindexregister',
                'op_module'       => 'user',
                'op_controll'     => 'navbar',
                'op_action'       => 'login',
                'op_order'        => 902,
            ],
            [
                'nav_text'        => '用户中心',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'center',
                'nav_action'      => 'index',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-user',
                'nav_active'      => 'usercenterindex',
                'op_module'       => 'user',
                'op_controll'     => 'navbar',
                'op_action'       => 'logout',
                'op_order'        => 903,
            ],
            [
                'nav_text'        => '安全退出',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'index',
                'nav_action'      => 'logout',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-sign-out',
                'nav_active'      => 'userindexlogout',
                'op_module'       => 'user',
                'op_controll'     => 'navbar',
                'op_action'       => 'logout',
                'op_order'        => 904,
            ],
        ]);
        //批量添加菜单
        $result = model('navs/Db','loglic')->save_all([
            [
                'nav_text'        => '用户中心',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'center',
                'nav_action'      => 'index',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-user',
                'nav_active'      => 'usercenterindex',
                'op_module'       => 'user',
                'op_controll'     => 'navs',
                'op_action'       => 'left',
                'op_order'        => 951,
            ],
            [
                'nav_text'        => '修改密码',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'center',
                'nav_action'      => 'repwd',
                'nav_params'      => '',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-exchange',
                'nav_active'      => 'usercenterrepwd',
                'op_module'       => 'user',

                'op_controll'     => 'navs',
                'op_action'       => 'left',
                'op_order'        => 952,
            ],
            [
                'nav_text'        => '安全退出',
                'nav_type'        => 'addon',
                'nav_module'      => 'user',
                'nav_controll'    => 'index',
                'nav_action'      => 'logout',
                'nav_params'      => 'login',
                'nav_target'      =>'_self',
                'nav_ico'         => 'fa fa-fw fa-sign-out',
                'nav_active'      => 'userindexlogout',
                'op_module'       => 'user',
                'op_controll'     => 'navs',
                'op_action'       => 'left',
                'op_order'        => 999,
            ],
        ]);
        
        return true;
    }
	
}